@@ -193,7 +193,7 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
         # read in scipy.netcdf mode to obtain varariable offsets
         
         vsdin.append(dict())
-        if type(datin[idatin]['file'])__name__ == 'list':
+        if type(datin[idatin]['file']).__name__ == 'list':
             ncfn =  datin[idatin]['file'][0]
             nctemp = netcdf_file(ncfn,'r')
             vsdin[idatin]['dnams'] = []
@@ -755,10 +755,10 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
     # # vsdin[ivsdin]['refdstd']: references of data stream dimensions (vsdin[..]['dnams'] to the standard dimensions (dnamsstd) 
     # dnamselnoiter: references
 
-    print ('dims in:',vsdin[ivsdin]['dims'])
-    print ('dnams in:',vsdin[ivsdin]['dnams'])
-    print ('dims out:',vsdout[ivsdin]['dims'])
-    print ('dnams out:',vsdout[ivsdin]['dnams'])
+    # print ('dims in:',vsdin[ivsdin]['dims'])
+    # print ('dnams in:',vsdin[ivsdin]['dnams'])
+    # print ('dims out:',vsdout[ivsdin]['dims'])
+    # print ('dnams out:',vsdout[ivsdin]['dnams'])
     
     # guess from residual dimensions that are not in refnoiterin
     refditerstd = []
